@@ -162,12 +162,16 @@ def encode_output(string, encoding):
 
 def helpline(obj):
     """
-    Yield an object's first docstring line, or an empty string.
+    Yield an object's first docstring line, or None if there was no docstring.
 
     .. versionadded:: 1.0
     """
     docstring = obj.__doc__
-    if not docstring or docstring == type(obj).__doc__:
+    if (
+        not docstring
+        or not docstring.strip()
+        or docstring == type(obj).__doc__
+    ):
         return None
     return docstring.lstrip().splitlines()[0]
 
@@ -271,8 +275,7 @@ class ExceptionHandlingThread(threading.Thread):
         # NOTE: it seems highly unlikely that a thread could still be
         # is_alive() but also have encountered an exception. But hey. Why not
         # be thorough?
-        alive = self.is_alive() and (self.exc_info is None)
-        return not alive
+        return (not self.is_alive()) and self.exc_info is not None
 
     def __repr__(self):
         # TODO: beef this up more
